@@ -54,7 +54,7 @@ enum BoxDecoration {
     Slice,
 }
 
-/// https://tailwindcss.com/docs/box-sizing
+#[doc = include_str!("box-decoration-break.md")]
 #[derive(Copy, Clone, Debug)]
 pub struct TailwindBoxDecoration {
     kind: BoxDecoration,
@@ -66,7 +66,7 @@ enum BoxSizing {
     Content,
 }
 
-/// https://tailwindcss.com/docs/box-sizing
+#[doc = include_str!("box-sizing.md")]
 #[derive(Copy, Clone, Debug)]
 pub struct TailwindBoxSizing {
     kind: BoxSizing,
@@ -92,7 +92,7 @@ pub enum FloatKind {
     None,
 }
 
-/// https://tailwindcss.com/docs/float
+#[doc = include_str!("float.md")]
 #[derive(Copy, Clone, Debug)]
 pub struct TailwindFloat {
     kind: FloatKind,
@@ -106,37 +106,26 @@ enum ClearKind {
     None,
 }
 
-/// https://tailwindcss.com/docs/clear
+#[doc = include_str!("clear.md")]
 #[derive(Copy, Clone, Debug)]
 pub struct TailwindClear {
     kind: ClearKind,
 }
 
-#[doc = include_str ! ("z-index.md")]
 #[derive(Copy, Clone, Debug)]
-pub enum TailWindZIndex {
-    Auto,
-    Positive(usize),
-    Negative(usize),
-}
-
-#[doc = include_str ! ("box-sizing.md")]
-#[derive(Copy, Clone, Debug)]
-pub enum TailWindBoxSizing {
-    Auto,
-    Positive(isize),
-    Negative(isize),
-}
-
-#[derive(Copy, Clone, Debug)]
-pub enum TailwindIsolation {
+enum IsolationKind {
     Isolate,
     Auto,
 }
 
-/// https://tailwindcss.com/docs/object-fit
+///
 #[derive(Copy, Clone, Debug)]
-pub enum TailwindObjectFit {
+pub struct TailwindIsolation {
+    kind: IsolationKind,
+}
+
+#[derive(Copy, Clone, Debug)]
+enum ObjectFitKind {
     Contain,
     Cover,
     Fill,
@@ -144,6 +133,12 @@ pub enum TailwindObjectFit {
     ScaleDown,
 }
 
+/// https://tailwindcss.com/docs/object-fit
+#[derive(Copy, Clone, Debug)]
+pub struct TailwindObjectFit {
+    kind: ObjectFitKind,
+}
+
 /// https://tailwindcss.com/docs/object-fit
 #[derive(Clone, Debug)]
 pub enum TailwindObjectPosition {
@@ -158,6 +153,23 @@ pub enum TailwindObjectPosition {
     RightBottom,
     Custom { x: String, y: String },
 }
+
+#[doc = include_str ! ("z-index.md")]
+#[derive(Copy, Clone, Debug)]
+pub enum TailWindZIndex {
+    Auto,
+    Positive(usize),
+    Negative(usize),
+}
+
+#[doc = include_str!("box-sizing.md")]
+#[derive(Copy, Clone, Debug)]
+pub enum TailWindBoxSizing {
+    Auto,
+    Positive(isize),
+    Negative(isize),
+}
+
 #[derive(Copy, Clone, Debug)]
 enum OverflowKind {
     Auto,
