@@ -160,31 +160,6 @@ impl TailwindOverscroll {
     }
 }
 
-impl TailWindZIndex {
-    pub fn parse(kind: &[&str], neg: bool) -> Box<dyn TailwindInstance> {
-        match kind.len() {
-            1 => {}
-            r => panic!("break-inside expected 1 element but found {} elements", r),
-        }
-        let instance = match kind {
-            ["auto"] => Self::Auto,
-            [r] => Self::parse_number(r, neg).expect("not number"),
-            _ => {
-                panic!("Unknown aspect-ratio pattern")
-            }
-        };
-        Box::new(instance)
-    }
-    #[inline]
-    fn parse_number(input: &str, neg: bool) -> Result<Self> {
-        let n = parse_integer(input)?.1;
-        match neg {
-            true => Ok(Self::Negative(n)),
-            false => Ok(Self::Positive(n)),
-        }
-    }
-}
-
 impl TailwindFloat {
     /// https://tailwindcss.com/docs/float
     pub fn parse(kind: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
@@ -214,8 +189,28 @@ impl TailwindClear {
     }
 }
 
+impl TailwindObjectFit {
+    /// `object-contain`
+    pub const Contain: Self = Self { kind: ObjectFitKind::Contain };
+    /// `object-cover`
+    pub const Cover: Self = Self { kind: ObjectFitKind::Cover };
+    /// `object-fill`
+    pub const Fill: Self = Self { kind: ObjectFitKind::Fill };
+    /// `object-none`
+    pub const None: Self = Self { kind: ObjectFitKind::None };
+    /// `object-scale-down`
+    pub const ScaleDown: Self = Self { kind: ObjectFitKind::ScaleDown };
+}
+
+impl TailwindIsolation {
+    /// `isolate`
+    pub const Isolate: Self = Self { kind: IsolationKind::Isolate };
+    /// `isolation-auto`
+    pub const Auto: Self = Self { kind: IsolationKind::Auto };
+}
+
 impl TailwindBoxDecoration {
-    ///
+    /// ``
     pub const Clone: Self = Self { kind: BoxDecoration::Clone };
     ///
     pub const Slice: Self = Self { kind: BoxDecoration::Slice };
@@ -227,3 +222,28 @@ impl TailwindBoxSizing {
     ///
     pub const Content: Self = Self { kind: BoxSizing::Content };
 }
+
+impl TailWindZIndex {
+    pub fn parse(kind: &[&str], neg: bool) -> Box<dyn TailwindInstance> {
+        match kind.len() {
+            1 => {}
+            r => panic!("break-inside expected 1 element but found {} elements", r),
+        }
+        let instance = match kind {
+            ["auto"] => Self::Auto,
+            [r] => Self::parse_number(r, neg).expect("not number"),
+            _ => {
+                panic!("Unknown aspect-ratio pattern")
+            }
+        };
+        Box::new(instance)
+    }
+    #[inline]
+    fn parse_number(input: &str, neg: bool) -> Result<Self> {
+        let n = parse_integer(input)?.1;
+        match neg {
+            true => Ok(Self::Negative(n)),
+            false => Ok(Self::Positive(n)),
+        }
+    }
+}
