@@ -1,3 +1,4 @@
+#![allow(non_upper_case_globals)]
 pub mod accessibility;
 pub mod background;
 pub mod borders;
@@ -13,15 +14,13 @@ pub mod transforms;
 pub mod transition;
 pub mod typography;
 
-use crate::{
-    css_attributes, parse_f32, parse_f_percent, parse_i_px_maybe, parse_integer, syntax_error, traits::CssAttribute,
-    ColorResolver, CssBehavior, LengthUnit, TailwindBrightness, TailwindBuilder, TailwindInstance, TailwindObjectPosition,
-};
+use crate::*;
 use std::{
     collections::{BTreeSet, HashMap},
     fmt::{Debug, Display, Formatter, Write},
     str::FromStr,
 };
+use tailwind_ast::{parse_f32, parse_f_percent, parse_fraction, parse_i_px_maybe, parse_integer};
 use tailwind_error::{
     nom::{branch::alt, bytes::complete::tag, combinator::opt, sequence::tuple, IResult},
     Result,
